==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/he.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
    "Step 1 failed. Exception: %s" : "שלב 1 נכשל. חריג: %s",
    "Step 2 failed. Exception: %s" : "שלב 2 נכשל. חריג: %s",
    "External storage" : "אחסון חיצוני",
    "Storage with id \"%i\" not found" : "אחסון עם מספר זיהוי \"%i\" לא אותר",
    "Invalid backend or authentication mechanism class" : "צד אחורי או סוג מנגנון אימות לא חוקי",
    "Invalid mount point" : "נקודת עגינה לא חוקית",
    "Objectstore forbidden" : "Objectstore חסום",
    "Invalid storage backend \"%s\"" : "צד אחורי של האחסון אינו תקין \"%s\"",
    "Not permitted to use backend \"%s\"" : "השימוש בצד אחורי \"%s\" אינו מותר",
    "Not permitted to use authentication mechanism \"%s\"" : "השימוש במכניזם אימות \"%s\" אינו מותר",
    "Unsatisfied backend parameters" : "פרמטרים צד אחורי אינם מספקים",
    "Unsatisfied authentication mechanism parameters" : "פרמטרים של מכניזם אימות אינם מספקים",
    "Insufficient data: %s" : "מידע לא מספק: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "האחסון עם זהות \"%i\" לא ניתן לעריכה",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Grant access" : "הענקת גישה",
    "Access granted" : "הוענקה גישה",
    "Error configuring OAuth1" : "שגיאה בתצורת OAuth1",
    "Error configuring OAuth2" : "שגיאה בתצורת OAuth2",
    "Generate keys" : "יצירת מפתחות",
    "Error generating key pair" : "שגיאה ביצירת זוג מפתחות",
    "Enable encryption" : "אפשר הצפנה",
    "Enable previews" : "מאפשר תצוגות מקדימות",
    "Enable sharing" : "הפעלת שיתוף",
    "Check for changes" : "בדיקה אחר שינויים",
    "Never" : "לעולם לא",
    "Once every direct access" : "פעם אחת כל כניסה ישירה",
    "All users. Type to select user or group." : "כל המשתמשים. יש להקיש לבחירת משתמש או קבוצה.",
    "(group)" : "(קבוצה)",
    "Admin defined" : "הוגדר מנהל",
    "Saved" : "נשמר",
    "Empty response from the server" : "תגובה ריקה מהשרת",
    "Couldn't access. Please logout and login to activate this mount point" : "לא ניתן להכנס. יש להתנתק ולהתחבר כדי להפעיל את נקודת העיגון הזו",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "לא ניתן היה לקבל את המידע משרת ה- ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "לא ניתן היה לקבל את רשימת נקודות העיגון החיצוניות: {type}",
    "There was an error with message: " : "התרחשה שגיאה עם הודעה: ",
    "External mount error" : "שגיאת עגינה חיצונית",
    "external-storage" : "אחסון חיצוני",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "לא ניתן היה לקבל את רשימת נקודות העיגון של כונן הרשת של Window: תגובה ריקה מהשרת",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "חלק מנקודות העיגון החיצוניות שהוגדרו אינן מחוברות. יש ללחוץ על השורה/ות האדומה/ות למידע נוסף",
    "Please enter the credentials for the {mount} mount" : "יש להזין את פרטי הגישה עבור התקן עגינה {mount}",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Credentials saved" : "פרטי גישה נשמרו",
    "Credentials saving failed" : "שמירת פרטי גישה נכשלה",
    "Credentials required" : "נדרשים פרטי גישה",
    "Save" : "שמירה",
    "Access key" : "מפתח כניסה",
    "Secret key" : "מפתח סודי",
    "Builtin" : "מובנה",
    "None" : "כלום",
    "OAuth1" : "OAuth1",
    "App key" : "מפתח יישום",
    "App secret" : "סוד יישום",
    "OAuth2" : "OAuth2",
    "Client ID" : "זיהוי לקוח",
    "Client secret" : "סוד לקוח",
    "OpenStack" : "OpenStack",
    "Tenant name" : "שם דייר",
    "Identity endpoint URL" : "זהות נתיב נקודת קצה",
    "Rackspace" : "חץ אחורה",
    "API key" : "מפתח API",
    "Username and password" : "שם משתמש וסיסמא",
    "Log-in credentials, save in session" : "אישורי התחברות, נשמרים במידע שיחה - סשן",
    "RSA public key" : "מפתח ציבורי RSA",
    "Public key" : "מפתח ציבורי",
    "Amazon S3" : "אמזון S3",
    "Bucket" : "סל",
    "Hostname" : "שם מארח",
    "Port" : "שער",
    "Region" : "אזור",
    "Enable SSL" : "הפעלת SSL",
    "Enable Path Style" : "אהפעלת סגנון נתיב",
    "WebDAV" : "WebDAV",
    "URL" : "נתיב אינטרנט",
    "Remote subfolder" : "תיקיית משנה רחוקה",
    "Secure https://" : "פרוטוקול מאובטח https://",
    "Dropbox" : "דרופבוקס",
    "FTP" : "FTP",
    "Host" : "מארח",
    "Secure ftps://" : "פרוטוקול מאובטח ftps://",
    "Google Drive" : "גוגל דרייב",
    "Local" : "מקומי",
    "Location" : "מיקום",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "נתיב ראשי",
    "SFTP with secret key login" : "SFTP עם מפתח כניסה סודי",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "שיתוף",
    "Domain" : "שם תחום",
    "SMB / CIFS using OC login" : "SMB / CIFS בשימוש עם כניסת OC",
    "Username as share" : "שם משתמש כשיתוף",
    "OpenStack Object Storage" : "אחסון אובייקט OpenStack",
    "Service name" : "שם שירות",
    "Request timeout (seconds)" : "פסק זמן מבוקש (שניות)",
    "<b>Note:</b> " : "<b>הערה:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>הערה:</b> תמיכת ה- cURL ב- PHP אינה מופעלת או מותקנת. חיבור של %s אינו אפשרי. יש לבקש ממנהל המערכת להתקין אותה.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>הערה:</b> תמיכת ה- FTP ב- PHP אינה מופעלת או מותקנת. חיבור של %s אינו אפשרי. יש לבקש ממנהל המערכת להתקין אותה.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>הערה:</b> \"%s\" אינו מותקן. חיבור של %s אינו אפשרי. יש לבקש ממנהל המערכת להתקין אותה.",
    "No external storage configured" : "לא מוגדר אחסון חיצוני",
    "You can add external storages in the personal settings" : "ניתן להוסיף אחסונים חיצוניים בהגדרות האישיות",
    "Name" : "שם",
    "Storage type" : "סוג אחסון",
    "Scope" : "היקף",
    "External Storage" : "אחסון חיצוני",
    "Folder name" : "שם התיקייה",
    "Authentication" : "אימות",
    "Configuration" : "הגדרות",
    "Available for" : "זמין עבור",
    "Add storage" : "הוספת אחסון",
    "Advanced settings" : "הגדרות מתקדמות",
    "Delete" : "מחיקה",
    "Allow users to mount external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני",
    "Allow users to mount the following external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני הבא",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "חלק מנקודות העיגון החיצוניות שהוגדרו אינן מחוברות. יש ללחוץ על השורה/ות האדומה/ות למידע נוסף"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/he.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
    "Step 1 failed. Exception: %s" : "שלב 1 נכשל. חריג: %s",
    "Step 2 failed. Exception: %s" : "שלב 2 נכשל. חריג: %s",
    "External storage" : "אחסון חיצוני",
    "Dropbox App Configuration" : "הגדרות יישום דרופבוקס",
    "Google Drive App Configuration" : "הגדרות יישום גוגל דרייב",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Grant access" : "הענקת גישה",
    "Error configuring OAuth1" : "שגיאה בתצורת OAuth1",
    "Error configuring OAuth2" : "שגיאה בתצורת OAuth2",
    "Generate keys" : "יצירת מפתחות",
    "Error generating key pair" : "שגיאה ביצירת זוג מפתחות",
    "All users. Type to select user or group." : "כל המשתמשים. יש להקיש לבחירת משתמש או קבוצה.",
    "(group)" : "(קבוצה)",
    "Compatibility with Mac NFD encoding (slow)" : "תואם של קידוד Mac NFD (איטי)",
    "Admin defined" : "הוגדר מנהל",
    "Saved" : "נשמר",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "נטרול אחסון חיצוני יסיר את כל האחסונים של כל המשתמשים, האם הנך בטוח?",
    "Disable external storage" : "נטרול אחסון חיצוני",
    "Empty response from the server" : "תגובה ריקה מהשרת",
    "Couldn't access. Please logout and login to activate this mount point" : "לא ניתן להכנס. יש להתנתק ולהתחבר כדי להפעיל את נקודת העיגון הזו",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "לא ניתן היה לקבל את המידע משרת ה- ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "לא ניתן היה לקבל את רשימת נקודות העיגון החיצוניות: {type}",
    "There was an error with message: " : "התרחשה שגיאה עם הודעה: ",
    "External mount error" : "שגיאת עגינה חיצונית",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "לא ניתן היה לקבל את רשימת נקודות העיגון של כונן הרשת של Window: תגובה ריקה מהשרת",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "חלק מנקודות העיגון החיצוניות שהוגדרו אינן מחוברות. יש ללחוץ על השורה/ות האדומה/ות למידע נוסף",
    "Please enter the credentials for the {mount} mount" : "יש להזין את פרטי הגישה עבור התקן עגינה {mount}",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Credentials saved" : "פרטי גישה נשמרו",
    "Credentials saving failed" : "שמירת פרטי גישה נכשלה",
    "Credentials required" : "נדרשים פרטי גישה",
    "Save" : "שמירה",
    "Storage with id \"%i\" not found" : "אחסון עם מספר זיהוי \"%i\" לא אותר",
    "Invalid backend or authentication mechanism class" : "צד אחורי או סוג מנגנון אימות לא חוקי",
    "Invalid mount point" : "נקודת עגינה לא חוקית",
    "Objectstore forbidden" : "Objectstore חסום",
    "Invalid storage backend \"%s\"" : "צד אחורי של האחסון אינו תקין \"%s\"",
    "Not permitted to use backend \"%s\"" : "השימוש בצד אחורי \"%s\" אינו מותר",
    "Not permitted to use authentication mechanism \"%s\"" : "השימוש במכניזם אימות \"%s\" אינו מותר",
    "Unsatisfied backend parameters" : "פרמטרים צד אחורי אינם מספקים",
    "Unsatisfied authentication mechanism parameters" : "פרמטרים של מכניזם אימות אינם מספקים",
    "Insufficient data: %s" : "מידע לא מספק: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "האחסון עם זהות \"%i\" לא ניתן לעריכה",
    "Access key" : "מפתח כניסה",
    "Secret key" : "מפתח סודי",
    "OAuth1" : "OAuth1",
    "App key" : "מפתח יישום",
    "App secret" : "סוד יישום",
    "OAuth2" : "OAuth2",
    "Client ID" : "זיהוי לקוח",
    "Client secret" : "סוד לקוח",
    "OpenStack" : "OpenStack",
    "Tenant name" : "שם דייר",
    "Identity endpoint URL" : "זהות נתיב נקודת קצה",
    "Rackspace" : "חץ אחורה",
    "API key" : "מפתח API",
    "RSA public key" : "מפתח ציבורי RSA",
    "Public key" : "מפתח ציבורי",
    "Amazon S3" : "אמזון S3",
    "Bucket" : "סל",
    "Hostname" : "שם מארח",
    "Port" : "שער",
    "Region" : "אזור",
    "Enable SSL" : "הפעלת SSL",
    "Enable Path Style" : "אהפעלת סגנון נתיב",
    "WebDAV" : "WebDAV",
    "URL" : "נתיב אינטרנט",
    "Remote subfolder" : "תיקיית משנה רחוקה",
    "Secure https://" : "פרוטוקול מאובטח https://",
    "Dropbox" : "דרופבוקס",
    "Google Drive" : "גוגל דרייב",
    "Local" : "מקומי",
    "Location" : "מיקום",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "מארח",
    "Root" : "נתיב ראשי",
    "SFTP with secret key login" : "SFTP עם מפתח כניסה סודי",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "שיתוף",
    "Domain" : "שם תחום",
    "SMB / CIFS using OC login" : "SMB / CIFS בשימוש עם כניסת OC",
    "Username as share" : "שם משתמש כשיתוף",
    "OpenStack Object Storage" : "אחסון אובייקט OpenStack",
    "Service name" : "שם שירות",
    "Request timeout (seconds)" : "פסק זמן מבוקש (שניות)",
    "<b>Note:</b> " : "<b>הערה:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>הערה:</b> תמיכת ה- cURL ב- PHP אינה מופעלת או מותקנת. חיבור של %s אינו אפשרי. יש לבקש ממנהל המערכת להתקין אותה.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>הערה:</b> \"%s\" אינו מותקן. חיבור של %s אינו אפשרי. יש לבקש ממנהל המערכת להתקין אותה.",
    "No external storage configured" : "לא מוגדר אחסון חיצוני",
    "You can add external storages in the storage settings" : "ניתן להוסיף זכרונות חיצוניים בהגדרות הזכרון",
    "Name" : "שם",
    "Storage type" : "סוג אחסון",
    "Scope" : "היקף",
    "Enable encryption" : "אפשר הצפנה",
    "Enable previews" : "מאפשר תצוגות מקדימות",
    "Enable sharing" : "הפעלת שיתוף",
    "Check for changes" : "בדיקה אחר שינויים",
    "Never" : "לעולם לא",
    "Once every direct access" : "פעם אחת כל כניסה ישירה",
    "External Storage" : "אחסון חיצוני",
    "Enable external storage" : "הפעלת אחסון חיצוני",
    "External storage has been disabled by the administrator" : "אחסון חיצוני הופעל על ידי המנהל",
    "Folder name" : "שם התיקייה",
    "Authentication" : "אימות",
    "Configuration" : "הגדרות",
    "Available for" : "זמין עבור",
    "Add storage" : "הוספת אחסון",
    "Advanced settings" : "הגדרות מתקדמות",
    "Delete" : "מחיקה",
    "Allow users to mount external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני",
    "Allow users to mount the following external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני הבא"
},
"nplurals=2; plural=(n != 1);");
